import { createApp } from "vue";
import { OpenAPI, UsersService } from "@/services/openapi";
import App from "./App.vue";
import router from "./router";
import store from "./store";
import PrimeVue from "primevue/config";
import ConfirmationService from "primevue/confirmationservice";
import ToastService from "primevue/toastservice";
import { library } from "@fortawesome/fontawesome-svg-core";
import { FontAwesomeIcon } from "@fortawesome/vue-fontawesome";
import { faMugHot } from "@fortawesome/free-solid-svg-icons";
import { faChampagneGlasses } from "@fortawesome/free-solid-svg-icons";
import { faCheese } from "@fortawesome/free-solid-svg-icons";
library.add(faMugHot, faChampagneGlasses, faCheese);

import "primevue/resources/primevue.min.css";
import "primeicons/primeicons.css";
import "primeflex/primeflex.css";

export const API_ENDPOINT_URL = window.origin + "/api";
export const WEBSOCKET_ENDPOINT_URL = API_ENDPOINT_URL.replace("http", "ws") + "/orders/ws";
OpenAPI.BASE = API_ENDPOINT_URL;

async function getHealth() {
  const response = await fetch(API_ENDPOINT_URL + "/health");
  const groups = response.headers.get("remote-groups")?.split(",");
  store.commit("setGroups", groups);
  const user = await UsersService.getUsers(response.headers.get("remote-name") || "Benutzer");
  store.commit("setUser", user);
}

getHealth().then(() => {
  const app = createApp(App);
  app.use(store);
  app.use(router);
  app.use(PrimeVue, {
    locale: {
      startsWith: "Beginnt mit",
      contains: "enthält",
      notContains: "enthält nicht",
      endsWith: "endet mit",
      equals: "entspricht",
      notEquals: "entspricht nicht",
      noFilter: "Kein Filter",
      lt: "Weniger als",
      lte: "Weniger als oder gleich viel",
      gt: "Mehr als",
      gte: "Mehr als oder gleich viel",
      dateIs: "Datum ist",
      dateIsNot: "Datum ist nicht",
      dateBefore: "Datum liegt vor",
      dateAfter: "Datum liegt nach",
      clear: "Löschen",
      apply: "Anwenden",
      matchAll: "Alle abgleichen",
      matchAny: "Mit jedem abgleichen",
      addRule: "Regel hinzufügen",
      removeRule: "Regel entfernen",
      accept: "Ja",
      reject: "Nein",
      choose: "Auswählen",
      upload: "Hochladen",
      cancel: "Abbrechen",
      dayNames: ["Sonntag", "Montag", "Dienstag", "Mittwoch", "Donnerstag", "Freitag", "Samstag"],
      dayNamesShort: ["Son", "Mon", "Die", "Mit", "Don", "Fre", "Sam"],
      dayNamesMin: ["So", "Mo", "Di", "Mi", "Do", "Fr", "Sa"],
      monthNames: ["Januar", "Februar", "März", "April", "Mai", "Juni", "Juli", "August", "September", "Oktober", "November", "Dezember"],
      monthNamesShort: ["Jan", "Feb", "Mär", "Apr", "Mai", "Jun", "Jul", "Aug", "Sep", "Okt", "Nov", "Dez"],
      today: "Heute",
      weekHeader: "Wo",
      firstDayOfWeek: 1,
      dateFormat: "dd.mm.yy",
      weak: "Schwach",
      medium: "Medium",
      strong: "Stark",
      passwordPrompt: "Passwort eingeben",
      emptySearchMessage: "Keine Ergebnisse gefunden",
      emptyMessage: "Keine verfügbaren Optionen",
      aria: {
        trueLabel: "True",
        falseLabel: "False",
        nullLabel: "Nicht ausgewählt",
        star: "1 Stern",
        stars: "{star} Sterne",
        selectAll: "Alle Artikel ausgewählt",
        unselectAll: "Alle Artikel nicht ausgewählt",
        close: "Schließen",
        previous: "Vorherig",
        next: "Nächste",
        navigation: "Navigation",
        scrollTop: "Nach Oben scrollen",
        moveTop: "Nach oben bewegen",
        moveUp: "Aufsteigen",
        moveDown: "Absteigen",
        moveBottom: "Nach unten bewegen",
        moveToTarget: "Move to Target",
        moveToSource: "Move to Source",
        moveAllToTarget: "Move All to Target",
        moveAllToSource: "Move All to Source",
        pageLabel: "{page}",
        firstPageLabel: "Erste Seite",
        lastPageLabel: "Letzte Seite",
        nextPageLabel: "Nächste Seite",
        prevPageLabel: "Vorherige Seite",
        rowsPerPageLabel: "Reihen pro Seite",
        jumpToPageDropdownLabel: "Jump to Page Dropdown",
        jumpToPageInputLabel: "Jump to Page Input",
        selectRow: "Reihe ausgewählt",
        unselectRow: "Reihe abgewählt",
        expandRow: "Row Expanded",
        collapseRow: "Row Collapsed",
        showFilterMenu: "Show Filter Menu",
        hideFilterMenu: "Hide Filter Menu",
        filterOperator: "Filter Operator",
        filterConstraint: "Filter Constraint",
        editRow: "Row Edit",
        saveEdit: "Save Edit",
        cancelEdit: "Cancel Edit",
        listView: "List View",
        gridView: "Grid View",
        slide: "Slide",
        slideNumber: "{slideNumber}",
        zoomImage: "Zoom Image",
        zoomIn: "Zoom In",
        zoomOut: "Zoom Out",
        rotateRight: "Rotate Right",
        rotateLeft: "Rotate Left",
      },
    },
  });
  app.use(ConfirmationService);
  app.use(ToastService);
  app.component("font-awesome-icon", FontAwesomeIcon);

  router.isReady().then(() => {
    app.mount("#app");
  });
});
